@@ -19,45 +19,41 @@
 #ifndef STRINGEXPRESSIONWRITER_H
 #define STRINGEXPRESSIONWRITER_H
 
-#include "abstractexpressionvisitor.h"
+#include "expressionwriter.h"
 #include "operator.h"
 
 namespace Analitza
 {
 
 /**
- * \class StringExpressionWriter
- * 
- * \ingroup AnalitzaModule
+ *	This class represents the string expression writer.
  *
- * \brief This class represents the string expression writer.
+ *	@author Aleix Pol <aleixpol@kde.org>  
  */
 
-class StringExpressionWriter : public AbstractExpressionVisitor
+class StringExpressionWriter : public ExpressionWriter
 {
 	public:
 		StringExpressionWriter(const Object* o);
 		
-		virtual QVariant visit(const Ci* var);
-		virtual QVariant visit(const Cn* var);
-		virtual QVariant visit(const Container* var);
-		virtual QVariant visit(const Operator* var);
-		virtual QVariant visit(const Vector* var);
-		virtual QVariant visit(const List* l);
-		virtual QVariant visit(const Matrix* m);
-		virtual QVariant visit(const MatrixRow* mr);
-		virtual QVariant visit(const Apply* a);
-		virtual QVariant visit(const CustomObject* c);
+		virtual QString accept(const Ci* var);
+		virtual QString accept(const Cn* var);
+		virtual QString accept(const Container* var);
+		virtual QString accept(const Operator* var);
+		virtual QString accept(const Vector* var);
+		virtual QString accept(const List* l);
+		virtual QString accept(const Apply* a);
+		virtual QString accept(const CustomObject* c);
 		
-		QVariant result() const { return m_result; }
+		QString result() const { return m_result; }
 		
 		static int weight(const Analitza::Operator* op, int size, int pos);
 		static const QMap<Operator::OperatorType, QString> s_operators;
 	private:
 		template <class T>
-			static QStringList allValues(T it, const T& itEnd, AbstractExpressionVisitor* writer);
+			static QStringList allValues(T it, const T& itEnd, ExpressionWriter* writer);
 
-		QVariant m_result;
+		QString m_result;
 };
 
 }
